## parzen-windows

Description: A Python module that will take input (training data) and estimate the underlying probability density function with Parzen Windows





To build run 
`python3 -m build` 
while in the `parzen_windows` directory
then navigate to `./dist` directory


Then run 

`twine upload dist/*`
or 
`twine upload --skip-existing dist/*`